"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-template-curly-in-string */
const __1 = require("../../..");
beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
    require('dotenv').config({ path: './config/countries.env' });
    yield __1.orm.init('./config/countries.yaml');
}));
describe('nullable', () => {
    const context = JSON.parse('{}');
    test('normalize', () => {
        expect(__1.orm.normalize('States.filter(p=> isNull(p.latitude)).map(p=> count(1))')).toStrictEqual('States.map(p=>count(1)).filter(p=>isNull(p.latitude))');
        expect(__1.orm.normalize('States.filter(p=> isNotNull(p.latitude)).map(p=> count(1))')).toStrictEqual('States.map(p=>count(1)).filter(p=>isNotNull(p.latitude))');
        expect(__1.orm.normalize('States.filter(p=> nvl(p.latitude,-100)== -100).map(p=> count(1))')).toStrictEqual('States.map(p=>count(1)).filter(p=>(nvl(p.latitude,-100)==-100))');
        expect(__1.orm.normalize('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl(p.native,"???")})')).toStrictEqual('Countries.map(p=>{native:nvl(p.native,???)}).filter(p=>(p.iso3==CIV))');
        expect(__1.orm.normalize('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl2(p.native,"is not null","is null")})')).toStrictEqual('Countries.map(p=>{native:nvl2(p.native,is not null,is null)}).filter(p=>(p.iso3==CIV))');
    });
    test('model', () => {
        expect(__1.orm.model('States.filter(p=> isNull(p.latitude)).map(p=> count(1))')).toStrictEqual([]);
        expect(__1.orm.model('States.filter(p=> isNotNull(p.latitude)).map(p=> count(1))')).toStrictEqual([]);
        expect(__1.orm.model('States.filter(p=> nvl(p.latitude,-100)== -100).map(p=> count(1))')).toStrictEqual([]);
        expect(__1.orm.model('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl(p.native,"???")})')).toStrictEqual([{ 'name': 'native', 'type': 'string' }]);
        expect(__1.orm.model('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl2(p.native,"is not null","is null")})')).toStrictEqual([{ 'name': 'native', 'type': 'string' }]);
    });
    test('parameters', () => {
        expect(__1.orm.parameters('States.filter(p=> isNull(p.latitude)).map(p=> count(1))')).toStrictEqual([]);
        expect(__1.orm.parameters('States.filter(p=> isNotNull(p.latitude)).map(p=> count(1))')).toStrictEqual([]);
        expect(__1.orm.parameters('States.filter(p=> nvl(p.latitude,-100)== -100).map(p=> count(1))')).toStrictEqual([]);
        expect(__1.orm.parameters('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl(p.native,"???")})')).toStrictEqual([]);
        expect(__1.orm.parameters('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl2(p.native,"is not null","is null")})')).toStrictEqual([]);
    });
    test('constraints', () => {
        expect(__1.orm.constraints('States.filter(p=> isNull(p.latitude)).map(p=> count(1))')).toStrictEqual({ "entity": "States", "constraints": [] });
        expect(__1.orm.constraints('States.filter(p=> isNotNull(p.latitude)).map(p=> count(1))')).toStrictEqual({ "entity": "States", "constraints": [] });
        expect(__1.orm.constraints('States.filter(p=> nvl(p.latitude,-100)== -100).map(p=> count(1))')).toStrictEqual({ "entity": "States", "constraints": [] });
        expect(__1.orm.constraints('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl(p.native,"???")})')).toStrictEqual({ "entity": "Countries", "constraints": [] });
        expect(__1.orm.constraints('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl2(p.native,"is not null","is null")})')).toStrictEqual({ "entity": "Countries", "constraints": [] });
    });
    test('getInfo', () => {
        expect(__1.orm.plan('States.filter(p=> isNull(p.latitude)).map(p=> count(1))', { stage: 'stage1' })).toStrictEqual({ "entity": "States", "dialect": "PostgreSQL", "source": "dataSource2", "sentence": "SELECT COUNT(1) FROM TBL_STATES s  WHERE (s.LATITUDE IS NULL) " });
        expect(__1.orm.plan('States.filter(p=> isNotNull(p.latitude)).map(p=> count(1))', { stage: 'stage1' })).toStrictEqual({ "entity": "States", "dialect": "PostgreSQL", "source": "dataSource2", "sentence": "SELECT COUNT(1) FROM TBL_STATES s  WHERE (s.LATITUDE IS NOT NULL) " });
        expect(__1.orm.plan('States.filter(p=> nvl(p.latitude,-100)== -100).map(p=> count(1))', { stage: 'stage1' })).toStrictEqual({ "entity": "States", "dialect": "PostgreSQL", "source": "dataSource2", "sentence": "SELECT COUNT(1) FROM TBL_STATES s  WHERE (CASE WHEN s.LATITUDE IS NOT NULL THEN s.LATITUDE ELSE -100 END) = -100 " });
        expect(__1.orm.plan('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl(p.native,"???")})', { stage: 'stage1' })).toStrictEqual({ "entity": "Countries", "dialect": "MySQL", "source": "dataSource1", "sentence": "SELECT IFNULL(c.native,'???') AS native FROM Countries c  WHERE c.iso3 = 'CIV' " });
        expect(__1.orm.plan('Countries.filter(p=> p.iso3 == "CIV" ).map(p=> {native: nvl2(p.native,"is not null","is null")})', { stage: 'stage1' })).toStrictEqual({ "entity": "Countries", "dialect": "MySQL", "source": "dataSource1", "sentence": "SELECT (CASE WHEN c.native IS NOT NULL THEN 'is not null' ELSE 'is null' END) AS native FROM Countries c  WHERE c.iso3 = 'CIV' " });
    });
});
//# sourceMappingURL=nullable.test.js.map